====================
Django Debug Toolbar
====================

.. image:: https://jazzband.co/static/img/badge.svg
   :target: https://jazzband.co/
   :alt: Jazzband

.. image:: https://github.com/jazzband/django-debug-toolbar/workflows/Test/badge.svg
   :target: https://github.com/jazzband/django-debug-toolbar/actions
   :alt: Build Status

.. image:: https://codecov.io/gh/jazzband/django-debug-toolbar/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/jazzband/django-debug-toolbar
   :alt: Test coverage status

.. image:: https://img.shields.io/pypi/pyversions/django-debug-toolbar
   :target: https://pypi.python.org/pypi/django-debug-toolbar
   :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/djversions/django-debug-toolbar
   :target: https://pypi.org/project/django-debug-toolbar
   :alt: Supported Django versions

The Django Debug Toolbar is a configurable set of panels that display various
debug information about the current request/response and when clicked, display
more details about the panel's content.

Here's a screenshot of the toolbar in action:

.. image:: https://raw.github.com/jazzband/django-debug-toolbar/master/example/django-debug-toolbar.png
   :alt: Django Debug Toolbar screenshot

In addition to the built-in panels, a number of third-party panels are
contributed by the community.

The current stable version of the Debug Toolbar is 3.2. It works on
Django ≥ 2.2.

Documentation, including installation and configuration instructions, is
available at https://django-debug-toolbar.readthedocs.io/.

The Django Debug Toolbar is released under the BSD license, like Django
itself. If you like it, please consider contributing!

The Django Debug Toolbar was originally created by Rob Hudson <rob@cogit8.org>
in August 2008 and was further developed by many contributors_.

.. _contributors: https://github.com/jazzband/django-debug-toolbar/graphs/contributors
